@@ -26,8 +26,9 @@ import yaml
 from collections import defaultdict
 from contextlib import contextmanager
 
-from .core import Scannable, LogFileOutput, Parser, IniConfigFile  # noqa: F401
+from .core import Scannable, LogFileOutput, IniConfigFile  # noqa: F401
 from .core import FileListing, LegacyItemAccess, SysconfigOptions  # noqa: F401
+from .core import Parser, ContainerParser  # noqa: F401
 from .core import YAMLParser, JSONParser, XMLParser, CommandParser  # noqa: F401
 from .core import AttributeDict  # noqa: F401
 from .core import Syslog  # noqa: F401
