@@ -23,7 +23,6 @@ from .connection import InsightsConnection
 from .archive import InsightsArchive
 from .support import registration_check
 from .constants import InsightsConstants as constants
-from .schedule import get_scheduler
 
 NETWORK = constants.custom_network_log_level
 LOG_FORMAT = ("%(asctime)s %(levelname)8s %(name)s %(message)s")
@@ -200,16 +199,18 @@ def get_registration_status(config, pconn):
     return registration_check(pconn)
 
 
+def __cleanup_local_files():
+    write_unregistered_file()
+    delete_cache_files()
+    write_to_disk(constants.machine_id_file, delete=True)
+    logger.debug('Unregistered and removed machine-id')
+
+
 # -LEGACY-
 def _legacy_handle_unregistration(config, pconn):
     """
         returns (bool): True success, False failure
     """
-    def __cleanup_local_files():
-        write_unregistered_file()
-        get_scheduler(config).remove_scheduling()
-        delete_cache_files()
-        write_to_disk(constants.machine_id_file, delete=True)
 
     check = get_registration_status(config, pconn)
 
@@ -248,10 +249,7 @@ def handle_unregistration(config, pconn):
     unreg = pconn.unregister()
     if unreg or config.force:
         # only set if unreg was successful or --force was set
-        write_unregistered_file()
-        delete_cache_files()
-        write_to_disk(constants.machine_id_file, delete=True)
-        logger.debug('Unregistered and removed machine-id')
+        __cleanup_local_files()
     return unreg
 
 
@@ -316,7 +314,12 @@ def _legacy_upload(config, pconn, tar_file, content_type, collection_duration=No
     logger.info('Uploading Insights data.')
     api_response = None
     for tries in range(config.retries):
-        upload = pconn.upload_archive(tar_file, '', collection_duration)
+        logger.debug("Legacy upload attempt %d of %d ...", tries + 1, config.retries)
+        try:
+            upload = pconn.upload_archive(tar_file, '', collection_duration)
+        except Exception as e:
+            display_upload_error_and_retry(config, tries, str(e))
+            continue
 
         if upload.status_code in (200, 201):
             api_response = json.loads(upload.text)
@@ -347,16 +350,7 @@ def _legacy_upload(config, pconn, tar_file, content_type, collection_duration=No
             pconn.handle_fail_rcs(upload)
             raise RuntimeError('Upload failed.')
         else:
-            logger.error("Upload attempt %d of %d failed! Status Code: %s",
-                         tries + 1, config.retries, upload.status_code)
-            if tries + 1 != config.retries:
-                logger.info("Waiting %d seconds then retrying",
-                            constants.sleep_time)
-                time.sleep(constants.sleep_time)
-            else:
-                logger.error("All attempts to upload have failed!")
-                print("Please see %s for additional information" % config.logging_file)
-                raise RuntimeError('Upload failed.')
+            display_upload_error_and_retry(config, tries, "%s: %s" % (upload.status_code, upload.reason))
     return api_response
 
 
@@ -365,7 +359,12 @@ def upload(config, pconn, tar_file, content_type, collection_duration=None):
         return _legacy_upload(config, pconn, tar_file, content_type, collection_duration)
     logger.info('Uploading Insights data.')
     for tries in range(config.retries):
-        upload = pconn.upload_archive(tar_file, content_type, collection_duration)
+        logger.debug("Upload attempt %d of %d ...", tries + 1, config.retries)
+        try:
+            upload = pconn.upload_archive(tar_file, content_type, collection_duration)
+        except Exception as e:
+            display_upload_error_and_retry(config, tries, str(e))
+            continue
 
         if upload.status_code in (200, 202):
             write_to_disk(constants.lastupload_file)
@@ -380,13 +379,20 @@ def upload(config, pconn, tar_file, content_type, collection_duration=None):
             pconn.handle_fail_rcs(upload)
             raise RuntimeError('Upload failed.')
         else:
-            logger.error("Upload attempt %d of %d failed! Status code: %s",
-                         tries + 1, config.retries, upload.status_code)
-            if tries + 1 != config.retries:
-                logger.info("Waiting %d seconds then retrying",
-                            constants.sleep_time)
-                time.sleep(constants.sleep_time)
-            else:
-                logger.error("All attempts to upload have failed!")
-                print("Please see %s for additional information" % config.logging_file)
-                raise RuntimeError('Upload failed.')
+            err_msg = "%s" % upload.status_code
+            if hasattr(upload, 'reason'):
+                err_msg += ": %s" % upload.reason
+            display_upload_error_and_retry(config, tries, err_msg)
+
+
+def display_upload_error_and_retry(config, tries, error_message):
+    logger.error("Upload attempt %d of %d failed! Reason: %s",
+                 tries + 1, config.retries, error_message)
+    if tries + 1 < config.retries:
+        logger.info("Waiting %d seconds then retrying",
+                    constants.sleep_time)
+        time.sleep(constants.sleep_time)
+    else:
+        logger.error("All attempts to upload have failed!")
+        print("Please see %s for additional information" % config.logging_file)
+        raise RuntimeError('Upload failed.')
