@@ -127,6 +127,14 @@ DEFAULT_OPTS = {
         'group': 'actions',
         'dest': 'app'
     },
+    'manifest': {
+        'default': None,
+        'opt': ['--manifest'],
+        'help': 'Collect using the provided manifest',
+        'action': 'store',
+        'group': 'actions',
+        'dest': 'manifest'
+    },
     'compliance': {
         'default': False,
         'opt': ['--compliance'],
@@ -243,6 +251,10 @@ DEFAULT_OPTS = {
         # non-CLI
         'default': False,  # legacy
     },
+    'no_proxy': {
+        # non-CLI
+        'default': None
+    },
     'no_upload': {
         'default': False,
         'opt': ['--no-upload'],
@@ -464,6 +476,7 @@ class InsightsConfig(object):
     '''
     Insights client configuration
     '''
+
     def __init__(self, *args, **kwargs):
         # this is only used to print configuration errors upon initial load
         self._print_errors = False
@@ -833,8 +846,10 @@ class InsightsConfig(object):
         Config values may have been set manually however, so need to take that into consideration
         '''
         if self.app == 'malware-detection':
-            if self.retries < 5:
-                self.retries = 5
+            # Add extra retries for malware, mainly because it could take a long time to run
+            # and the results archive shouldn't be discarded after a single failed upload attempt
+            if self.retries < 3:
+                self.retries = 3
 
     def _determine_filename_and_extension(self):
         '''
