@@ -51,8 +51,17 @@ class CoreCollector(DataCollector):
 
         manifest = collect.default_manifest
         if hasattr(self.config, 'manifest') and self.config.manifest:
-            manifest = self.config.manifest
-        collected_data_path = collect.collect(manifest=manifest, tmp_path=self.archive.tmp_dir, rm_conf=core_blacklist, client_timeout=self.config.cmd_timeout)
+            if self.config.app is None:
+                with open(self.config.manifest, 'r') as f:
+                    manifest = f.read()
+            else:
+                manifest = self.config.manifest
+        collected_data_path, exceptions = collect.collect(
+            manifest=manifest,
+            tmp_path=self.archive.tmp_dir,
+            rm_conf=core_blacklist,
+            client_timeout=self.config.cmd_timeout
+        )
 
         # update the archive dir with the reported data location from Insights Core
         if not collected_data_path:
