@@ -11,6 +11,7 @@ from __future__ import print_function
 import argparse
 import logging
 import os
+import sys
 import tempfile
 import yaml
 
@@ -164,6 +165,10 @@ plugins:
         - name: insights.combiners.httpd_conf._HttpdConf
           enabled: true
 
+    # needed for httpd_on_nfs
+        - name: insights.parsers.mount.ProcMounts
+          enabled: true
+
     # needed for nginx_ssl_cert_enddate
         - name: insights.combiners.nginx_conf.NginxConfTree
           enabled: true
@@ -205,10 +210,18 @@ plugins:
     # needed for the 'pre-check' of the 'is_satellite_server' spec
         - name: insights.combiners.satellite_version.SatelliteVersion
           enabled: true
+        - name: insights.components.satellite.IsSatellite
+          enabled: true
 
     # needed for the 'pre-check' of the 'is_satellite_capsule' spec
         - name: insights.combiners.satellite_version.CapsuleVersion
           enabled: true
+        - name: insights.components.satellite.IsCapsule
+          enabled: true
+
+    # needed for the 'pre-check' of the 'satellite_provision_param_settings' spec
+        - name: insights.components.satellite.IsSatellite611
+          enabled: true
 
     # needed for the 'pre-check' of the 'corosync_cmapctl_cmd_list' spec
         - name: insights.combiners.redhat_release.RedHatRelease
@@ -228,11 +241,30 @@ plugins:
         - name: insights.parsers.ros_config.RosConfig
           enabled: true
 
+    # needed for the 'container' specs
+        - name: insights.parsers.podman_list.PodmanListContainers
+          enabled: true
+
+        - name: insights.parsers.docker_list.DockerListContainers
+          enabled: true
+
     # needed because some specs aren't given names before they're used in DefaultSpecs
         - name: insights.core.spec_factory
           enabled: true
+
+    # needed by the 'luks_data_sources' spec
+        - name: insights.parsers.blkid.BlockIDInfo
+          enabled: true
+
+        - name: insights.components.cryptsetup
+          enabled: true
 """.strip()
 
+EXCEPTIONS_TO_REPORT = set([
+    OSError
+])
+"""Exception types that should be reported on after core collection."""
+
 
 def load_manifest(data):
     """ Helper for loading a manifest yaml doc. """
@@ -339,7 +371,10 @@ def collect(manifest=default_manifest, tmp_path=None, compress=False, rm_conf=No
             into the manifest blacklist.
         client_timeout (int): Client-provided command timeout value
     Returns:
-        The full path to the created tar.gz or workspace.
+        (str, dict): The full path to the created tar.gz or workspace.
+        And a dictionary with relevant exceptions captured by the broker during
+        core collection, this dictionary has the following structure:
+        ``{ exception_type: [ (exception_obj, component), (exception_obj, component) ]}``.
     """
 
     manifest = load_manifest(manifest)
@@ -402,12 +437,48 @@ def collect(manifest=default_manifest, tmp_path=None, compress=False, rm_conf=No
         broker.add_observer(h.make_persister(to_persist))
         dr.run_all(broker=broker, pool=pool)
 
+    collect_errors = _parse_broker_exceptions(broker, EXCEPTIONS_TO_REPORT)
+
     if compress:
-        return create_archive(output_path)
-    return output_path
+        return create_archive(output_path), collect_errors
+    return output_path, collect_errors
+
+
+def _parse_broker_exceptions(broker, exceptions_to_report):
+    """
+    Parse the exceptions captured in the broker during core collection
+    and keep only exception types configured in the ``exceptions_to_report``.
+
+    Args:
+        broker (Broker): Broker object used for core collection.
+        exceptions_to_report (set): Exception types to retrieve from the broker.
+
+    Returns:
+        (dict): A dictionary with relevant exceptions captured by the broker.
+    """
+    errors = {}
+    try:
+        if broker.exceptions:
+            for component, exceptions in broker.exceptions.items():
+                for ex in exceptions:
+                    ex_type = type(ex)
+                    if ex_type in exceptions_to_report:
+                        if ex_type in errors.keys():
+                            errors[ex_type].append((ex, component))
+                        else:
+                            errors[ex_type] = [(ex, component)]
+    except Exception as e:
+        log.warning("Could not parse exceptions from the broker.: %s", str(e))
+    return errors
 
 
 def main():
+    # Remove command line args so that they are not parsed by any called modules
+    # The main fxn is only invoked as a cli, if calling from another cli then
+    # use the collect function instead
+    collect_args = [arg for arg in sys.argv[1:]] if len(sys.argv) > 1 else []
+    sys.argv = [sys.argv[0], ] if sys.argv else sys.argv
+
     p = argparse.ArgumentParser()
     p.add_argument("-m", "--manifest", help="Manifest yaml.")
     p.add_argument("-o", "--out_path", help="Path to write output data.")
@@ -415,7 +486,7 @@ def main():
     p.add_argument("-v", "--verbose", help="Verbose output.", action="store_true")
     p.add_argument("-d", "--debug", help="Debug output.", action="store_true")
     p.add_argument("-c", "--compress", help="Compress", action="store_true")
-    args = p.parse_args()
+    args = p.parse_args(args=collect_args)
 
     level = logging.WARNING
     if args.verbose:
@@ -434,7 +505,7 @@ def main():
         manifest = default_manifest
 
     out_path = args.out_path or tempfile.gettempdir()
-    archive = collect(manifest, out_path, compress=args.compress)
+    archive, errors = collect(manifest, out_path, compress=args.compress)
     print(archive)
 
 
