@@ -47,7 +47,8 @@ class PackageProvidesHttpdAll(LegacyItemAccess):
     def __init__(self, package_provides_httpd):
         deprecated(
             PackageProvidesHttpdAll,
-            'Please use the :class:`insights.parsers.package_provides.PackageProvidesCommand` instead.'
+            "Please use the :class:`insights.parsers.package_provides.PackageProvidesCommand` instead.",
+            "3.0.300"
         )
         self.data = {}
         for pkg in package_provides_httpd:
