@@ -361,6 +361,69 @@ def get_dependency_graph(component):
     return graph
 
 
+def get_dependency_specs(component):
+    """
+    Get the dependency specs of the specified `component`. Only `requires` and
+    `at_least_one` specs will be returned. The `optional` specs is not
+    considered in this function.
+
+    Arguments:
+        component (callable): The component to check. The component must
+            already be loaded.
+
+    Returns:
+        list: The `requires` and `at_least_one` spec sets of the `component`.
+
+    The return list is in the following format::
+
+         [
+             requires_1,
+             requires_2,
+             (at_least_one_11, at_least_one_12),
+             (at_least_one_21, [req_alo22, (alo_23, alo_24)]),
+         ]
+
+        Note:
+         - The 'requires_1' and 'requires_2' are `requires` specs.
+           Each of them are required.
+         - The 'at_least_one_11' and 'at_least_one_12' are `at_least_one`
+           specs in the same at least one set.
+           At least one of them is required
+         - The 'alo_23' and 'alo_24' are `at_least_one` specs and
+           together with the 'req_alo22' are `requires` for the
+           sub-set. This sub-set specs and the 'at_least_one_21' are
+           `at_least_one` specs in the same at least one set.
+    """
+    def get_requires(comp):
+        req = list()
+        for cmp in get_delegate(comp).requires:
+            if get_name(cmp).startswith("insights.specs."):
+                cmpn = get_simple_name(cmp)
+                req.append(cmpn) if cmpn not in req else None
+            else:
+                union = get_requires(cmp) + get_at_least_one(cmp)
+                req.extend([ss for ss in union if ss not in req])
+        return req
+
+    def get_at_least_one(comp):
+        alo = list()
+        for cmps in get_delegate(comp).at_least_one:
+            salo = list()
+            for cmp in cmps:
+                ssreq = get_requires(cmp)
+                ssalo = get_at_least_one(cmp)
+                if ssreq and ssalo:
+                    # they are mixed and in the same `requires` level
+                    salo.append([ss for ss in ssreq + ssalo if ss not in salo])
+                else:
+                    # no mixed, just add them one by one
+                    salo.extend([ss for ss in ssreq or ssalo if ss not in salo])
+            alo.append(tuple(salo))
+        return alo
+
+    return get_requires(component) + get_at_least_one(component)
+
+
 def get_subgraphs(graph=None):
     """
     Given a graph of possibly disconnected components, generate all graphs of
