@@ -131,6 +131,7 @@ class DockerListContainers(DockerList):
     Attributes:
         rows (list): List of row dictionaries.
         containers(dict): Dictionary keyed on the value of the "NAMES" field
+        running_containers(list): List of NAMEs of the running containers.
 
     Examples:
         >>> containers.rows[0]['STATUS']
@@ -143,6 +144,14 @@ class DockerListContainers(DockerList):
     attr_name = 'containers'
     substitutions = [("CONTAINER ID", "CONTAINER_ID")]
 
+    def __init__(self, *args, **kwargs):
+        super(DockerListContainers, self).__init__(*args, **kwargs)
+
+        self.running_containers = []
+        for name, info in self.containers.items():
+            if info.get('STATUS', '').startswith('Up '):
+                self.running_containers.append(name)
+
     @property
     def data(self):
         return self.containers
