@@ -7,21 +7,23 @@ class Specs(SpecSet):
     alternatives_display_python = RegistryPoint()
     amq_broker = RegistryPoint(multi_output=True)
     ansible_host = RegistryPoint()
+    audit_log = RegistryPoint(filterable=True)
     auditctl_rules = RegistryPoint()
     auditctl_status = RegistryPoint()
     auditd_conf = RegistryPoint()
-    audit_log = RegistryPoint(filterable=True)
+    authselect_current = RegistryPoint()
     autofs_conf = RegistryPoint()
-    avc_hash_stats = RegistryPoint()
     avc_cache_threshold = RegistryPoint()
+    avc_hash_stats = RegistryPoint()
     aws_instance_id_doc = RegistryPoint()
     aws_instance_id_pkcs7 = RegistryPoint()
     aws_instance_type = RegistryPoint()
     awx_manage_check_license = RegistryPoint()
     awx_manage_check_license_data = RegistryPoint(filterable=True)
     awx_manage_print_settings = RegistryPoint()
-    azure_instance_type = RegistryPoint()
+    azure_instance_id = RegistryPoint()
     azure_instance_plan = RegistryPoint()
+    azure_instance_type = RegistryPoint()
     bdi_read_ahead_kb = RegistryPoint(multi_output=True)
     bios_uuid = RegistryPoint()
     blkid = RegistryPoint()
@@ -33,11 +35,10 @@ class Specs(SpecSet):
     candlepin_broker = RegistryPoint()
     candlepin_error_log = RegistryPoint(filterable=True)
     candlepin_log = RegistryPoint(filterable=True)
-    cdc_wdm = RegistryPoint()
-    checkin_conf = RegistryPoint()
     catalina_out = RegistryPoint(multi_output=True, filterable=True)
     catalina_server_log = RegistryPoint(multi_output=True, filterable=True)
     cciss = RegistryPoint(multi_output=True)
+    cdc_wdm = RegistryPoint()
     ceilometer_central_log = RegistryPoint(filterable=True)
     ceilometer_collector_log = RegistryPoint(filterable=True)
     ceilometer_compute_log = RegistryPoint(filterable=True)
@@ -60,6 +61,7 @@ class Specs(SpecSet):
     ceph_v = RegistryPoint()
     certificates_enddate = RegistryPoint()
     cgroups = RegistryPoint()
+    checkin_conf = RegistryPoint()
     chkconfig = RegistryPoint()
     chrony_conf = RegistryPoint()
     chronyc_sources = RegistryPoint()
@@ -67,8 +69,9 @@ class Specs(SpecSet):
     cinder_api_log = RegistryPoint(filterable=True)
     cinder_conf = RegistryPoint()
     cinder_volume_log = RegistryPoint(filterable=True)
-    cloud_init_custom_network = RegistryPoint()
     cloud_cfg = RegistryPoint(filterable=True)
+    cloud_cfg_filtered = RegistryPoint()
+    cloud_init_custom_network = RegistryPoint()
     cloud_init_log = RegistryPoint(filterable=True)
     cluster_conf = RegistryPoint(filterable=True)
     cmdline = RegistryPoint()
@@ -85,37 +88,35 @@ class Specs(SpecSet):
     cpu_smt_active = RegistryPoint()
     cpu_smt_control = RegistryPoint()
     cpu_vulns = RegistryPoint(multi_output=True)
-    cpu_vulns_meltdown = RegistryPoint()
-    cpu_vulns_spectre_v1 = RegistryPoint()
-    cpu_vulns_spectre_v2 = RegistryPoint()
-    cpu_vulns_spec_store_bypass = RegistryPoint()
-    cpuinfo_max_freq = RegistryPoint()
     cpuinfo = RegistryPoint()
+    cpuinfo_max_freq = RegistryPoint()
     cpupower_frequency_info = RegistryPoint()
     cpuset_cpus = RegistryPoint()
     crictl_logs = RegistryPoint(multi_output=True, filterable=True)
     crio_conf = RegistryPoint(multi_output=True)
     cron_daily_rhsmd = RegistryPoint(filterable=True)
-    crypto_policies_config = RegistryPoint()
-    crypto_policies_state_current = RegistryPoint()
-    crypto_policies_opensshserver = RegistryPoint()
-    crypto_policies_bind = RegistryPoint()
+    cron_foreman = RegistryPoint(filterable=True)
     crt = RegistryPoint()
+    crypto_policies_bind = RegistryPoint()
+    crypto_policies_config = RegistryPoint()
+    crypto_policies_opensshserver = RegistryPoint()
+    crypto_policies_state_current = RegistryPoint()
+    cryptsetup_luksDump = RegistryPoint(multi_output=True)
     cups_ppd = RegistryPoint(multi_output=True)
     current_clocksource = RegistryPoint()
-    date_iso = RegistryPoint()
     date = RegistryPoint()
+    date_iso = RegistryPoint()
     date_utc = RegistryPoint()
     db2ls_a_c = RegistryPoint()
-    designate_conf = RegistryPoint(filterable=True)
     dcbtool_gc_dcb = RegistryPoint(multi_output=True)
-    df__alP = RegistryPoint()
+    designate_conf = RegistryPoint(filterable=True)
     df__al = RegistryPoint()
+    df__alP = RegistryPoint()
     df__li = RegistryPoint()
+    dig = RegistryPoint()
     dig_dnssec = RegistryPoint()
     dig_edns = RegistryPoint()
     dig_noedns = RegistryPoint()
-    dig = RegistryPoint()
     dirsrv = RegistryPoint()
     dirsrv_access = RegistryPoint(multi_output=True, filterable=True)
     dirsrv_errors = RegistryPoint(multi_output=True, filterable=True)
@@ -128,9 +129,9 @@ class Specs(SpecSet):
     dmsetup_info = RegistryPoint()
     dmsetup_status = RegistryPoint()
     dnf_conf = RegistryPoint(filterable=True)
-    dnf_modules = RegistryPoint()
-    dnf_module_list = RegistryPoint()
     dnf_module_info = RegistryPoint()
+    dnf_module_list = RegistryPoint()
+    dnf_modules = RegistryPoint()
     dnsmasq_config = RegistryPoint(multi_output=True)
     docker_container_inspect = RegistryPoint(multi_output=True)
     docker_host_machine_id = RegistryPoint()
@@ -151,23 +152,23 @@ class Specs(SpecSet):
     engine_config_all = RegistryPoint()
     engine_db_query_vdsm_version = RegistryPoint()
     engine_log = RegistryPoint(filterable=True)
-    etc_journald_conf_d = RegistryPoint(multi_output=True)
     etc_journald_conf = RegistryPoint()
+    etc_journald_conf_d = RegistryPoint(multi_output=True)
     etc_machine_id = RegistryPoint()
     etc_udev_40_redhat_rules = RegistryPoint(filterable=True)
     etc_udev_oracle_asm_rules = RegistryPoint(multi_output=True, filterable=True)
     etcd_conf = RegistryPoint(filterable=True)
-    ethernet_interfaces = RegistryPoint()
+    ethtool = RegistryPoint(multi_output=True)
+    ethtool_S = RegistryPoint(multi_output=True)
+    ethtool_T = RegistryPoint(multi_output=True)
     ethtool_a = RegistryPoint(multi_output=True)
     ethtool_c = RegistryPoint(multi_output=True)
     ethtool_g = RegistryPoint(multi_output=True)
     ethtool_i = RegistryPoint(multi_output=True)
     ethtool_k = RegistryPoint(multi_output=True)
-    ethtool = RegistryPoint(multi_output=True)
-    ethtool_S = RegistryPoint(multi_output=True)
-    ethtool_T = RegistryPoint(multi_output=True)
     exim_conf = RegistryPoint()
     facter = RegistryPoint()
+    fapolicyd_rules = RegistryPoint(multi_output=True, filterable=True)
     fc_match = RegistryPoint()
     fcoeadm_i = RegistryPoint()
     fdisk_l = RegistryPoint()
@@ -178,10 +179,10 @@ class Specs(SpecSet):
     foreman_production_log = RegistryPoint(filterable=True)
     foreman_proxy_conf = RegistryPoint()
     foreman_proxy_log = RegistryPoint(filterable=True)
+    foreman_rake_db_migrate_status = RegistryPoint()
     foreman_satellite_log = RegistryPoint(filterable=True)
     foreman_ssl_access_ssl_log = RegistryPoint(filterable=True)
     foreman_ssl_error_ssl_log = RegistryPoint(filterable=True)
-    foreman_rake_db_migrate_status = RegistryPoint()
     foreman_tasks_config = RegistryPoint(filterable=True)
     freeipa_healthcheck_log = RegistryPoint()
     fstab = RegistryPoint()
@@ -195,29 +196,28 @@ class Specs(SpecSet):
     getenforce = RegistryPoint()
     getsebool = RegistryPoint()
     gfs2_file_system_block_size = RegistryPoint(multi_output=True)
-    group_info = RegistryPoint(filterable=True)
     glance_api_conf = RegistryPoint()
     glance_api_log = RegistryPoint(filterable=True)
     glance_cache_conf = RegistryPoint()
     glance_registry_conf = RegistryPoint()
+    gluster_peer_status = RegistryPoint()
     gluster_v_info = RegistryPoint()
     gluster_v_status = RegistryPoint()
-    gluster_peer_status = RegistryPoint()
     gnocchi_conf = RegistryPoint(filterable=True)
     gnocchi_metricd_log = RegistryPoint(filterable=True)
     greenboot_status = RegistryPoint(filterable=True)
-    grubenv = RegistryPoint()
-    grub_conf = RegistryPoint()
-    grub_config_perms = RegistryPoint()
-    grub_efi_conf = RegistryPoint()
+    group_info = RegistryPoint(filterable=True)
     grub1_config_perms = RegistryPoint()
     grub2_cfg = RegistryPoint()
     grub2_efi_cfg = RegistryPoint()
+    grub_conf = RegistryPoint()
+    grub_config_perms = RegistryPoint()
+    grub_efi_conf = RegistryPoint()
     grubby_default_index = RegistryPoint()
     grubby_default_kernel = RegistryPoint()
+    grubenv = RegistryPoint()
     hammer_ping = RegistryPoint()
     hammer_task_list = RegistryPoint()
-    satellite_enabled_features = RegistryPoint()
     haproxy_cfg = RegistryPoint()
     haproxy_cfg_scl = RegistryPoint()
     heat_api_log = RegistryPoint(filterable=True)
@@ -230,61 +230,61 @@ class Specs(SpecSet):
     hostname_short = RegistryPoint()
     hosts = RegistryPoint()
     hponcfg_g = RegistryPoint()
+    httpd24_httpd_error_log = RegistryPoint(filterable=True)
+    httpd_M = RegistryPoint(multi_output=True)
+    httpd_V = RegistryPoint(multi_output=True)
     httpd_access_log = RegistryPoint(filterable=True)
     httpd_cert_info_in_nss = RegistryPoint(multi_output=True, filterable=True)
     httpd_conf = RegistryPoint(multi_output=True)
     httpd_conf_scl_httpd24 = RegistryPoint(multi_output=True)
     httpd_conf_scl_jbcs_httpd24 = RegistryPoint(multi_output=True)
     httpd_error_log = RegistryPoint(filterable=True)
-    httpd24_httpd_error_log = RegistryPoint(filterable=True)
-    jbcs_httpd24_httpd_error_log = RegistryPoint(filterable=True)
     httpd_limits = RegistryPoint(multi_output=True)
-    httpd_M = RegistryPoint(multi_output=True)
     httpd_on_nfs = RegistryPoint()
     httpd_ssl_access_log = RegistryPoint(filterable=True)
     httpd_ssl_cert_enddate = RegistryPoint(multi_output=True)
     httpd_ssl_error_log = RegistryPoint(filterable=True)
-    httpd_V = RegistryPoint(multi_output=True)
-    virt_uuid_facts = RegistryPoint()
     ibm_fw_vernum_encoded = RegistryPoint()
     ibm_lparcfg = RegistryPoint(filterable=True)
     ifcfg = RegistryPoint(multi_output=True)
     ifcfg_static_route = RegistryPoint(multi_output=True)
     ifconfig = RegistryPoint()
     imagemagick_policy = RegistryPoint(multi_output=True, filterable=True)
-    initctl_lst = RegistryPoint()
     init_ora = RegistryPoint()
-    initscript = RegistryPoint(multi_output=True)
     init_process_cgroup = RegistryPoint()
+    initctl_lst = RegistryPoint()
+    initscript = RegistryPoint(multi_output=True)
     insights_client_conf = RegistryPoint(filterable=True)
     installed_rpms = RegistryPoint()
     interrupts = RegistryPoint()
-    ip6tables_permanent = RegistryPoint()
     ip6tables = RegistryPoint()
+    ip6tables_permanent = RegistryPoint()
     ip_addr = RegistryPoint()
     ip_addresses = RegistryPoint()
+    ip_neigh_show = RegistryPoint()
+    ip_netns_exec_namespace_lsof = RegistryPoint(multi_output=True, filterable=True)
+    ip_route_show_table_all = RegistryPoint()
+    ip_s_link = RegistryPoint()
     ipaupgrade_log = RegistryPoint(filterable=True)
     ipcs_m = RegistryPoint()
     ipcs_m_p = RegistryPoint()
     ipcs_s = RegistryPoint()
     ipcs_s_i = RegistryPoint(multi_output=True)
-    ip_netns_exec_namespace_lsof = RegistryPoint(multi_output=True, filterable=True)
-    ip_route_show_table_all = RegistryPoint()
-    ip_s_link = RegistryPoint()
     ipsec_conf = RegistryPoint(filterable=True)
-    iptables_permanent = RegistryPoint()
     iptables = RegistryPoint()
+    iptables_permanent = RegistryPoint()
     ipv4_neigh = RegistryPoint()
     ipv6_neigh = RegistryPoint()
-    ip_neigh_show = RegistryPoint()
     ironic_conf = RegistryPoint(filterable=True)
     ironic_inspector_log = RegistryPoint(filterable=True)
     iscsiadm_m_session = RegistryPoint()
+    jbcs_httpd24_httpd_error_log = RegistryPoint(filterable=True)
     jboss_domain_server_log = RegistryPoint(multi_output=True, filterable=True)
-    jboss_standalone_server_log = RegistryPoint(multi_output=True, filterable=True)
     jboss_standalone_main_config = RegistryPoint(multi_output=True)
+    jboss_standalone_server_log = RegistryPoint(multi_output=True, filterable=True)
     jboss_version = RegistryPoint(multi_output=True)
     journal_all = RegistryPoint(filterable=True)
+    journal_header = RegistryPoint(filterable=True)
     journal_since_boot = RegistryPoint(filterable=True)
     katello_service_status = RegistryPoint(filterable=True)
     kdump_conf = RegistryPoint()
@@ -317,26 +317,30 @@ class Specs(SpecSet):
     lpfc_max_luns = RegistryPoint()
     lpstat_p = RegistryPoint()
     lpstat_protocol_printers = RegistryPoint()
+    ls_R_var_lib_nova_instances = RegistryPoint()
     ls_boot = RegistryPoint()
     ls_dev = RegistryPoint()
     ls_disk = RegistryPoint()
     ls_docker_volumes = RegistryPoint()
     ls_edac_mc = RegistryPoint()
     ls_etc = RegistryPoint()
+    ls_etc_ssh = RegistryPoint()
     ls_ipa_idoverride_memberof = RegistryPoint()
+    ls_krb5_sssd = RegistryPoint()
     ls_lib_firmware = RegistryPoint()
     ls_ocp_cni_openshift_sdn = RegistryPoint()
     ls_origin_local_volumes_pods = RegistryPoint()
     ls_osroot = RegistryPoint()
-    ls_R_var_lib_nova_instances = RegistryPoint()
     ls_sys_firmware = RegistryPoint()
     ls_systemd_units = RegistryPoint()
+    ls_tmp = RegistryPoint(filterable=True)
     ls_usr_bin = RegistryPoint(filterable=True)
     ls_usr_lib64 = RegistryPoint(filterable=True)
     ls_usr_sbin = RegistryPoint(filterable=True)
     ls_var_cache_pulp = RegistryPoint()
     ls_var_lib_mongodb = RegistryPoint()
     ls_var_lib_nova_instances = RegistryPoint()
+    ls_var_lib_pcp = RegistryPoint()
     ls_var_log = RegistryPoint()
     ls_var_opt_mssql = RegistryPoint()
     ls_var_opt_mssql_log = RegistryPoint()
@@ -345,7 +349,6 @@ class Specs(SpecSet):
     ls_var_spool_postfix_maildrop = RegistryPoint()
     ls_var_tmp = RegistryPoint(filterable=True)
     ls_var_www = RegistryPoint()
-    ls_tmp = RegistryPoint(filterable=True)
     lsblk = RegistryPoint()
     lsblk_pairs = RegistryPoint()
     lscpu = RegistryPoint()
@@ -358,66 +361,66 @@ class Specs(SpecSet):
     lssap = RegistryPoint()
     lsscsi = RegistryPoint()
     lsvmbus = RegistryPoint()
+    luksmeta = RegistryPoint(multi_output=True)
     lvdisplay = RegistryPoint()
     lvm_conf = RegistryPoint(filterable=True)
     lvm_system_devices = RegistryPoint()
     lvmconfig = RegistryPoint()
+    lvs = RegistryPoint()
     lvs_noheadings = RegistryPoint()
     lvs_noheadings_all = RegistryPoint()
-    lvs = RegistryPoint()
     mac_addresses = RegistryPoint(multi_output=True)
     machine_id = RegistryPoint()
     manila_conf = RegistryPoint()
     mariadb_log = RegistryPoint(filterable=True)
     max_uid = RegistryPoint()
-    mdadm_E = RegistryPoint(multi_output=True)
     md5chk_files = RegistryPoint(multi_output=True)
+    mdadm_E = RegistryPoint(multi_output=True)
     mdstat = RegistryPoint()
     meminfo = RegistryPoint()
     messages = RegistryPoint(filterable=True)
     metadata_json = RegistryPoint(raw=True)
-    satellite_missed_pulp_agent_queues = RegistryPoint()
     mistral_executor_log = RegistryPoint(filterable=True)
     mlx4_port = RegistryPoint(multi_output=True)
-    modinfo_i40e = RegistryPoint()
-    modinfo_igb = RegistryPoint()
-    modinfo_ixgbe = RegistryPoint()
-    modinfo_veth = RegistryPoint()
-    modinfo_vmxnet3 = RegistryPoint()
     modinfo = RegistryPoint(multi_output=True)
     modinfo_all = RegistryPoint()
     modinfo_filtered_modules = RegistryPoint()
+    modinfo_i40e = RegistryPoint()
+    modinfo_igb = RegistryPoint()
+    modinfo_ixgbe = RegistryPoint()
     modinfo_modules = RegistryPoint(filterable=True)
+    modinfo_veth = RegistryPoint()
+    modinfo_vmxnet3 = RegistryPoint()
     modprobe = RegistryPoint(multi_output=True)
     mokutil_sbstate = RegistryPoint()
     mongod_conf = RegistryPoint(multi_output=True, filterable=True)
     mount = RegistryPoint()
     mountinfo = RegistryPoint()
     mounts = RegistryPoint()
-    mssql_conf = RegistryPoint()
+    mpirun_version = RegistryPoint()
     mssql_api_assessment = RegistryPoint()
+    mssql_conf = RegistryPoint()
     mssql_tls_cert_enddate = RegistryPoint()
     multicast_querier = RegistryPoint()
+    multipath__v4__ll = RegistryPoint()
     multipath_conf = RegistryPoint()
     multipath_conf_initramfs = RegistryPoint()
-    multipath__v4__ll = RegistryPoint()
+    mysql_log = RegistryPoint(multi_output=True, filterable=True)
     mysqladmin_status = RegistryPoint()
     mysqladmin_vars = RegistryPoint()
-    mysql_log = RegistryPoint(multi_output=True, filterable=True)
     mysqld_limits = RegistryPoint()
     named_checkconf_p = RegistryPoint(filterable=True)
     named_conf = RegistryPoint(filterable=True)
     namespace = RegistryPoint()
     ndctl_list_Ni = RegistryPoint()
     netconsole = RegistryPoint()
+    netstat = RegistryPoint()
     netstat_agn = RegistryPoint()
     netstat_i = RegistryPoint()
-    netstat = RegistryPoint()
     netstat_s = RegistryPoint()
     networkmanager_conf = RegistryPoint()
     networkmanager_dispatcher_d = RegistryPoint(multi_output=True)
     neutron_conf = RegistryPoint(filterable=True)
-    neutron_sriov_agent = RegistryPoint(filterable=True)
     neutron_dhcp_agent_ini = RegistryPoint(filterable=True)
     neutron_l3_agent_ini = RegistryPoint(filterable=True)
     neutron_l3_agent_log = RegistryPoint(filterable=True)
@@ -427,10 +430,11 @@ class Specs(SpecSet):
     neutron_ovs_agent_log = RegistryPoint(filterable=True)
     neutron_plugin_ini = RegistryPoint()
     neutron_server_log = RegistryPoint(filterable=True)
+    neutron_sriov_agent = RegistryPoint(filterable=True)
     nfnetlink_queue = RegistryPoint()
     nfs_conf = RegistryPoint()
-    nfs_exports_d = RegistryPoint(multi_output=True)
     nfs_exports = RegistryPoint()
+    nfs_exports_d = RegistryPoint(multi_output=True)
     nginx_conf = RegistryPoint(multi_output=True)
     nginx_error_log = RegistryPoint(filterable=True)
     nginx_ssl_cert_enddate = RegistryPoint(multi_output=True)
@@ -442,8 +446,8 @@ class Specs(SpecSet):
     nova_conf = RegistryPoint()
     nova_crontab = RegistryPoint()
     nova_crontab_container = RegistryPoint()
-    nova_uid = RegistryPoint()
     nova_migration_uid = RegistryPoint()
+    nova_uid = RegistryPoint()
     nscd_conf = RegistryPoint(filterable=True)
     nss_rhel7 = RegistryPoint()
     nsswitch_conf = RegistryPoint(filterable=True)
@@ -458,6 +462,7 @@ class Specs(SpecSet):
     oc_get_build = RegistryPoint()
     oc_get_clusterrole_with_config = RegistryPoint()
     oc_get_clusterrolebinding_with_config = RegistryPoint()
+    oc_get_configmap = RegistryPoint()
     oc_get_dc = RegistryPoint()
     oc_get_egressnetworkpolicy = RegistryPoint()
     oc_get_endpoints = RegistryPoint()
@@ -465,31 +470,29 @@ class Specs(SpecSet):
     oc_get_node = RegistryPoint()
     oc_get_pod = RegistryPoint()
     oc_get_project = RegistryPoint()
-    oc_get_pvc = RegistryPoint()
     oc_get_pv = RegistryPoint()
+    oc_get_pvc = RegistryPoint()
     oc_get_rc = RegistryPoint()
-    oc_get_rolebinding = RegistryPoint()
     oc_get_role = RegistryPoint()
+    oc_get_rolebinding = RegistryPoint()
     oc_get_route = RegistryPoint()
     oc_get_service = RegistryPoint()
-    oc_get_configmap = RegistryPoint()
     octavia_conf = RegistryPoint(filterable=True)
     od_cpu_dma_latency = RegistryPoint()
     odbc_ini = RegistryPoint(filterable=True)
     odbcinst_ini = RegistryPoint()
     open_vm_tools_stat_raw_text_session = RegistryPoint()
-    openvswitch_other_config = RegistryPoint()
-    openvswitch_server_log = RegistryPoint(filterable=True)
     openshift_certificates = RegistryPoint(multi_output=True)
     openshift_fluentd_environ = RegistryPoint(multi_output=True)
     openshift_hosts = RegistryPoint(filterable=True)
     openshift_router_environ = RegistryPoint(multi_output=True)
     openvswitch_daemon_log = RegistryPoint(filterable=True)
+    openvswitch_other_config = RegistryPoint()
     openvswitch_server_log = RegistryPoint(filterable=True)
+    os_release = RegistryPoint()
     osa_dispatcher_log = RegistryPoint(filterable=True)
     ose_master_config = RegistryPoint()
     ose_node_config = RegistryPoint()
-    os_release = RegistryPoint()
     ovirt_engine_boot_log = RegistryPoint(filterable=True)
     ovirt_engine_confd = RegistryPoint(multi_output=True)
     ovirt_engine_console_log = RegistryPoint(filterable=True)
@@ -502,8 +505,8 @@ class Specs(SpecSet):
     ovs_vswitchd_limits = RegistryPoint()
     pacemaker_log = RegistryPoint(filterable=True)
     package_provides_command = RegistryPoint(filterable=True)
-    package_provides_java = RegistryPoint(multi_output=True)
     package_provides_httpd = RegistryPoint(multi_output=True)
+    package_provides_java = RegistryPoint(multi_output=True)
     pam_conf = RegistryPoint()
     parted__l = RegistryPoint()
     partitions = RegistryPoint()
@@ -522,8 +525,8 @@ class Specs(SpecSet):
     podman_image_inspect = RegistryPoint(multi_output=True)
     podman_list_containers = RegistryPoint()
     podman_list_images = RegistryPoint()
-    postconf_builtin = RegistryPoint(filterable=True)
     postconf = RegistryPoint(filterable=True)
+    postconf_builtin = RegistryPoint(filterable=True)
     postgresql_conf = RegistryPoint()
     postgresql_log = RegistryPoint(multi_output=True, filterable=True)
     prev_uploader_log = RegistryPoint()
@@ -541,12 +544,12 @@ class Specs(SpecSet):
     ps_eo = RegistryPoint()
     ps_eo_cmd = RegistryPoint()
     pulp_worker_defaults = RegistryPoint()
+    puppet_ca_cert_expire_date = RegistryPoint()
     puppet_ssl_cert_ca_pem = RegistryPoint()
     puppetserver_config = RegistryPoint(filterable=True)
-    puppet_ca_cert_expire_date = RegistryPoint()
+    pvs = RegistryPoint()
     pvs_noheadings = RegistryPoint()
     pvs_noheadings_all = RegistryPoint()
-    pvs = RegistryPoint()
     qemu_conf = RegistryPoint()
     qemu_xml = RegistryPoint(multi_output=True)
     ql2xmaxlun = RegistryPoint()
@@ -569,10 +572,10 @@ class Specs(SpecSet):
     readlink_e_etc_mtab = RegistryPoint()
     readlink_e_shift_cert_client = RegistryPoint()
     readlink_e_shift_cert_server = RegistryPoint()
+    recvq_socket_buffer = RegistryPoint()
     redhat_release = RegistryPoint()
     resolv_conf = RegistryPoint()
     rhev_data_center = RegistryPoint()
-    rhv_log_collector_analyzer = RegistryPoint()
     rhn_charsets = RegistryPoint()
     rhn_conf = RegistryPoint()
     rhn_entitlement_cert_xml = RegistryPoint(multi_output=True)
@@ -588,14 +591,16 @@ class Specs(SpecSet):
     rhsm_katello_default_ca_cert = RegistryPoint()
     rhsm_log = RegistryPoint(filterable=True)
     rhsm_releasever = RegistryPoint()
+    rhv_log_collector_analyzer = RegistryPoint()
     rndc_status = RegistryPoint()
     root_crontab = RegistryPoint()
     ros_config = RegistryPoint()
     route = RegistryPoint()
-    rpm_ostree_status = RegistryPoint()
     rpm_V_packages = RegistryPoint()
+    rpm_ostree_status = RegistryPoint()
     rsyslog_conf = RegistryPoint(filterable=True, multi_output=True)
     samba = RegistryPoint(filterable=True)
+    samba_logs = RegistryPoint(multi_output=True, filterable=True)
     sap_dev_disp = RegistryPoint(multi_output=True, filterable=True)
     sap_dev_rd = RegistryPoint(multi_output=True, filterable=True)
     sap_hana_landscape = RegistryPoint(multi_output=True)
@@ -611,61 +616,70 @@ class Specs(SpecSet):
     satellite_core_taskreservedresource_count = RegistryPoint()
     satellite_custom_ca_chain = RegistryPoint()
     satellite_custom_hiera = RegistryPoint()
+    satellite_enabled_features = RegistryPoint()
     satellite_katello_empty_url_repositories = RegistryPoint()
     satellite_katello_repos_with_muliple_ref = RegistryPoint()
+    satellite_logs_table_size = RegistryPoint()
+    satellite_missed_pulp_agent_queues = RegistryPoint()
     satellite_mongodb_storage_engine = RegistryPoint()
     satellite_non_yum_type_repos = RegistryPoint()
+    satellite_provision_param_settings = RegistryPoint()
     satellite_qualified_capsules = RegistryPoint()
     satellite_qualified_katello_repos = RegistryPoint()
     satellite_sca_status = RegistryPoint()
     satellite_settings = RegistryPoint()
     satellite_version_rb = RegistryPoint()
     satellite_yaml = RegistryPoint()
-    scheduler = RegistryPoint(multi_output=True)
     sched_rt_runtime_us = RegistryPoint()
+    scheduler = RegistryPoint(multi_output=True)
     scsi = RegistryPoint()
+    scsi_eh_deadline = RegistryPoint(multi_output=True)
+    scsi_fwver = RegistryPoint(multi_output=True)
     scsi_mod_max_report_luns = RegistryPoint()
     scsi_mod_use_blk_mq = RegistryPoint()
     sctp_asc = RegistryPoint()
     sctp_eps = RegistryPoint()
     sctp_snmp = RegistryPoint()
-    scsi_eh_deadline = RegistryPoint(multi_output=True)
-    scsi_fwver = RegistryPoint(multi_output=True)
     sealert = RegistryPoint()
     secure = RegistryPoint(filterable=True)
     selinux_config = RegistryPoint()
+    selinux_users = RegistryPoint(filterable=True)
+    sendq_socket_buffer = RegistryPoint()
     sestatus = RegistryPoint()
     setup_named_chroot = RegistryPoint(filterable=True)
     smartctl = RegistryPoint(multi_output=True)
     smartpdc_settings = RegistryPoint(filterable=True)
-    smbstatus_p = RegistryPoint()
     smbstatus_S = RegistryPoint()
+    smbstatus_p = RegistryPoint()
     sockstat = RegistryPoint()
     softnet_stat = RegistryPoint()
     software_collections_list = RegistryPoint()
     spamassassin_channels = RegistryPoint()
     spfile_ora = RegistryPoint(multi_output=True)
-    ssh_config_d = RegistryPoint(multi_output=True, filterable=True)
+    ss = RegistryPoint()
     ssh_config = RegistryPoint(filterable=True)
+    ssh_config_d = RegistryPoint(multi_output=True, filterable=True)
     ssh_foreman_config = RegistryPoint(filterable=True)
     ssh_foreman_proxy_config = RegistryPoint(filterable=True)
-    sshd_config_perms = RegistryPoint()
     sshd_config = RegistryPoint(filterable=True)
-    ss = RegistryPoint()
+    sshd_config_perms = RegistryPoint()
     sssd_config = RegistryPoint()
     sssd_logs = RegistryPoint(multi_output=True, filterable=True)
-    samba_logs = RegistryPoint(multi_output=True, filterable=True)
+    subscription_manager_facts = RegistryPoint(filterable=True)
     subscription_manager_id = RegistryPoint()
+    subscription_manager_installed_product_ids = RegistryPoint(filterable=True)
     subscription_manager_list_consumed = RegistryPoint()
     subscription_manager_list_installed = RegistryPoint()
-    subscription_manager_installed_product_ids = RegistryPoint(filterable=True)
     subscription_manager_release_show = RegistryPoint()
     sudoers = RegistryPoint(multi_output=True, filterable=True)
     swift_conf = RegistryPoint()
     swift_log = RegistryPoint(filterable=True)
     swift_object_expirer_conf = RegistryPoint()
     swift_proxy_server_conf = RegistryPoint()
+    sys_fs_cgroup_memory_tasks_number = RegistryPoint()
     sys_kernel_sched_features = RegistryPoint()
+    sys_vmbus_class_id = RegistryPoint(multi_output=True)
+    sys_vmbus_device_id = RegistryPoint(multi_output=True)
     sysconfig_chronyd = RegistryPoint()
     sysconfig_grub = RegistryPoint()
     sysconfig_httpd = RegistryPoint()
@@ -686,21 +700,20 @@ class Specs(SpecSet):
     sysctl_conf_initramfs = RegistryPoint(multi_output=True)
     sysctl_d_conf_etc = RegistryPoint(multi_output=True)
     sysctl_d_conf_usr = RegistryPoint(multi_output=True)
-    sys_fs_cgroup_memory_tasks_number = RegistryPoint()
     system_user_dirs = RegistryPoint()
     systemctl_cat_dnsmasq_service = RegistryPoint()
     systemctl_cat_rpcbind_socket = RegistryPoint()
     systemctl_cinder_volume = RegistryPoint()
     systemctl_httpd = RegistryPoint()
-    systemctl_nginx = RegistryPoint()
     systemctl_list_unit_files = RegistryPoint()
     systemctl_list_units = RegistryPoint()
     systemctl_mariadb = RegistryPoint()
-    systemctl_pulp_workers = RegistryPoint()
-    systemctl_pulp_resmg = RegistryPoint()
+    systemctl_nginx = RegistryPoint()
     systemctl_pulp_celerybeat = RegistryPoint()
-    systemctl_qpidd = RegistryPoint()
+    systemctl_pulp_resmg = RegistryPoint()
+    systemctl_pulp_workers = RegistryPoint()
     systemctl_qdrouterd = RegistryPoint()
+    systemctl_qpidd = RegistryPoint()
     systemctl_show_all_services = RegistryPoint()
     systemctl_show_all_services_with_limited_properties = RegistryPoint()
     systemctl_show_target = RegistryPoint()
@@ -714,13 +727,11 @@ class Specs(SpecSet):
     systemd_system_origin_accounting = RegistryPoint()
     systemid = RegistryPoint()
     systool_b_scsi_v = RegistryPoint()
-    sys_vmbus_device_id = RegistryPoint(multi_output=True)
-    sys_vmbus_class_id = RegistryPoint(multi_output=True)
-    testparm_s = RegistryPoint(filterable=True)
-    testparm_v_s = RegistryPoint(filterable=True)
     tags = RegistryPoint()
     teamdctl_config_dump = RegistryPoint(multi_output=True)
     teamdctl_state_dump = RegistryPoint(multi_output=True)
+    testparm_s = RegistryPoint(filterable=True)
+    testparm_v_s = RegistryPoint(filterable=True)
     thp_enabled = RegistryPoint()
     thp_use_zero_page = RegistryPoint()
     tmpfilesd = RegistryPoint(multi_output=True)
@@ -730,40 +741,42 @@ class Specs(SpecSet):
     tomcat_web_xml = RegistryPoint(multi_output=True)
     tuned_adm = RegistryPoint()
     tuned_conf = RegistryPoint()
-    udev_persistent_net_rules = RegistryPoint()
     udev_fc_wwpn_id_rules = RegistryPoint(filterable=True)
+    udev_persistent_net_rules = RegistryPoint()
     uname = RegistryPoint()
     up2date = RegistryPoint()
     up2date_log = RegistryPoint(filterable=True)
     uploader_log = RegistryPoint()
     uptime = RegistryPoint()
+    users_count_map_selinux_user = RegistryPoint()
     usr_journald_conf_d = RegistryPoint(multi_output=True)
     var_qemu_xml = RegistryPoint(multi_output=True)
+    vdo_status = RegistryPoint()
     vdsm_conf = RegistryPoint()
     vdsm_id = RegistryPoint()
     vdsm_import_log = RegistryPoint(multi_output=True, filterable=True)
     vdsm_log = RegistryPoint(filterable=True)
     vdsm_logger_conf = RegistryPoint()
     version_info = RegistryPoint()
-    vdo_status = RegistryPoint()
     vgdisplay = RegistryPoint()
+    vgs = RegistryPoint()
     vgs_noheadings = RegistryPoint()
     vgs_noheadings_all = RegistryPoint()
-    vgs = RegistryPoint()
     vhost_net_zero_copy_tx = RegistryPoint()
     virsh_list_all = RegistryPoint()
+    virt_uuid_facts = RegistryPoint()
     virt_what = RegistryPoint()
     virt_who_conf = RegistryPoint(multi_output=True, filterable=True)
     virtlogd_conf = RegistryPoint(filterable=True)
     vma_ra_enabled = RegistryPoint()
     vmcore_dmesg = RegistryPoint(multi_output=True, filterable=True)
     vmware_tools_conf = RegistryPoint()
-    vsftpd_conf = RegistryPoint(filterable=True)
     vsftpd = RegistryPoint()
+    vsftpd_conf = RegistryPoint(filterable=True)
     wc_proc_1_mountinfo = RegistryPoint()
-    x86_pti_enabled = RegistryPoint()
     x86_ibpb_enabled = RegistryPoint()
     x86_ibrs_enabled = RegistryPoint()
+    x86_pti_enabled = RegistryPoint()
     x86_retp_enabled = RegistryPoint()
     xfs_info = RegistryPoint(multi_output=True)
     xinetd_conf = RegistryPoint(multi_output=True)
@@ -777,5 +790,11 @@ class Specs(SpecSet):
     yum_updates = RegistryPoint()
     zdump_v = RegistryPoint()
     zipl_conf = RegistryPoint()
-    sendq_socket_buffer = RegistryPoint()
-    recvq_socket_buffer = RegistryPoint()
+
+    # container_specs
+    container_dotnet_version = RegistryPoint(multi_output=True)
+    container_redhat_release = RegistryPoint(multi_output=True)
+    container_nginx_conf = RegistryPoint(multi_output=True)
+    container_installed_rpms = RegistryPoint(multi_output=True)
+    container_inspect_keys = RegistryPoint(filterable=True)
+    containers_inspect = RegistryPoint()
