@@ -7,6 +7,7 @@ import time
 from insights import datasource, HostContext, SkipComponent
 from insights.components.rhel_version import IsRhel7, IsRhel8, IsRhel9
 from insights.core.spec_factory import DatasourceProvider
+from distutils.version import LooseVersion as version
 
 try:
     from functools import cmp_to_key
@@ -53,14 +54,15 @@ class DnfManager:
         self.base.conf.read()
         self.base.conf.cacheonly = True
         self.base.read_all_repos()
-        try:
-            # do not use standard self.base.fill_sack() it does not respect cacheonly
-            self.base.fill_sack_from_repos_in_cache(load_system_repo=True)
-            self.packages = self.base.sack.query()
-        except (dnf.exceptions.RepoError, AttributeError):
-            # RepoError is raised when cache is empty
-            # AttributeError is raised in dnf < 4.4 which can't handle cacheonly correctly
-            self.packages = hawkey.Query(hawkey.Sack())
+        self.packages = hawkey.Query(hawkey.Sack())
+        if version(dnf.VERSION) >= version("4.7.0"):
+            try:
+                # do not use standard self.base.fill_sack() it does not respect cacheonly
+                self.base.fill_sack_from_repos_in_cache(load_system_repo=True)
+                self.packages = self.base.sack.query()
+            except dnf.exceptions.RepoError:
+                # RepoError is raised when cache is empty
+                pass
         self.repos = self.base.repos
 
     def installed_packages(self):
@@ -210,7 +212,6 @@ def yum_updates(_broker):
     Raises:
         SkipComponent: Raised when neither dnf nor yum is found
     """
-
     if UpdatesManager is None:
         raise SkipComponent()
 
@@ -223,28 +224,30 @@ def yum_updates(_broker):
             "update_list": {},
         }
 
-        data = {'package_list': umgr.installed_packages()}
-        updates = {}
-        for pkg in data["package_list"]:
-            (nevra, updates_list) = umgr.updates(pkg)
-            updates[nevra] = updates_list
-            for (nevra, update_list) in updates.items():
-                if update_list:
-                    out_list = []
-                    for pkg in umgr.sorted_pkgs(update_list):
-                        pkg_dict = {
-                            "package": umgr.pkg_nevra(pkg),
-                            "repository": umgr.pkg_repo(pkg),
-                            "basearch": response["basearch"],
-                            "releasever": response["releasever"],
-                        }
-                        erratum = umgr.advisory(pkg)
-                        if erratum:
-                            pkg_dict["erratum"] = erratum
-                        out_list.append(pkg_dict)
-                    response["update_list"][nevra] = {"available_updates": out_list}
+        for pkg in umgr.installed_packages():
+            nevra, updates_list = umgr.updates(pkg)
+            if updates_list:
+                out_list = []
+                update_list = umgr.sorted_pkgs(updates_list)
+
+                for p in update_list:
+                    pkg_dict = {
+                        "package": umgr.pkg_nevra(p),
+                        "repository": umgr.pkg_repo(p),
+                        "basearch": response["basearch"],
+                        "releasever": response["releasever"],
+                    }
+
+                    erratum = umgr.advisory(p)
+                    if erratum:
+                        pkg_dict["erratum"] = erratum
+
+                    out_list.append(pkg_dict)
+
+                response["update_list"][nevra] = {"available_updates": out_list}
 
         ts = umgr.last_update()
         if ts:
             response["metadata_time"] = time.strftime("%FT%TZ", time.gmtime(ts))
+
     return DatasourceProvider(content=json.dumps(response), relative_path='insights_commands/yum_updates_list')
