@@ -152,6 +152,7 @@ def context_wrap(lines,
                  machine_id="machine_id",
                  strip=True,
                  split=True,
+                 filtered_spec=None,
                  **kwargs):
     if isinstance(lines, six.string_types):
         if strip:
@@ -159,6 +160,9 @@ def context_wrap(lines,
         if split:
             lines = lines.splitlines()
 
+    if filtered_spec is not None and filtered_spec in filters.FILTERS:
+        lines = [l for l in lines if any([f in l for f in filters.FILTERS[filtered_spec]])]
+
     return Context(content=lines,
                    path=path, hostname=hostname,
                    release=release, version=version.split("."),
