@@ -1,14 +1,20 @@
 import os
+import json
 
 from tempfile import mkdtemp
 from insights import dr
-from insights.core.plugins import component
+from insights.core.plugins import (component,
+                                   datasource,
+                                   rule,
+                                   make_info,
+                                   ContentException)
 from insights.core.serde import (serializer,
                                  deserializer,
                                  Hydration,
                                  marshal,
                                  unmarshal)
 from insights.util import fs
+from insights.core.spec_factory import RegistryPoint, SpecSet
 
 
 class Foo(object):
@@ -52,9 +58,26 @@ def deserialize_foo(_type, data, root=None):
     return foo
 
 
+class Specs(SpecSet):
+    the_data = RegistryPoint()
+
+
+class TestSpecs(Specs):
+    @datasource()
+    def the_data(broker):
+        raise ContentException('Fake Datasource')
+
+
+@rule(Specs.the_data)
+def report(dt):
+    return make_info('INFO_1')
+
+
 def test_marshal():
+    broker = dr.Broker()
     foo = Foo()
-    data, errors = marshal(foo)
+    broker[thing] = foo
+    data, errors = marshal(thing, broker)
     assert data
     assert not errors
     d = data["object"]
@@ -63,14 +86,18 @@ def test_marshal():
 
 
 def test_marshal_with_errors():
+    broker = dr.Broker()
     doo = Doo(2)
-    data, errors = marshal(doo)
+    broker[thing] = doo
+    data, errors = marshal(thing, broker)
     assert not data
     assert isinstance(errors, str)
 
     # one raises error, one has result
+    broker = dr.Broker()
     objs = [Doo(4), Doo(6)]
-    data, errors = marshal(objs)
+    broker[thing] = objs
+    data, errors = marshal(thing, broker)
     assert data
     assert errors
     assert len(data) == 1
@@ -80,15 +107,19 @@ def test_marshal_with_errors():
     assert d["b"] == 2
 
     # all raises error, no results
+    broker = dr.Broker()
     objs = [Doo(4), Doo(3)]
-    data, errors = marshal(objs)
+    broker[thing] = objs
+    data, errors = marshal(thing, broker)
     assert not data
     assert errors
     assert len(errors) == 2
 
     # all have resutls, no errors
+    broker = dr.Broker()
     objs = [Doo(8), Doo(6)]
-    data, errors = marshal(objs)
+    broker[thing] = objs
+    data, errors = marshal(thing, broker)
     assert data
     assert not errors
     assert len(data) == 2
@@ -103,8 +134,10 @@ def test_marshal_with_errors_with_pool():
         from concurrent.futures import ThreadPoolExecutor
         with ThreadPoolExecutor(thread_name_prefix="insights-collector-pool", max_workers=5) as pool:
             # one raises error, one has result
+            broker = dr.Broker()
             objs = [Doo(4), Doo(6)]
-            data, errors = marshal(objs, None, pool)
+            broker[thing] = objs
+            data, errors = marshal(thing, broker, pool=pool)
             assert data
             assert errors
             assert len(data) == 1
@@ -114,15 +147,19 @@ def test_marshal_with_errors_with_pool():
             assert d["b"] == 2
 
             # all raises error, no results
+            broker = dr.Broker()
             objs = [Doo(4), Doo(3)]
-            data, errors = marshal(objs, None, pool)
+            broker[thing] = objs
+            data, errors = marshal(thing, broker, pool=pool)
             assert not data
             assert errors
             assert len(errors) == 2
 
             # all have resutls, no errors
+            broker = dr.Broker()
             objs = [Doo(8), Doo(6)]
-            data, errors = marshal(objs, None, pool)
+            broker[thing] = objs
+            data, errors = marshal(thing, broker, pool=pool)
             assert data
             assert not errors
             assert len(data) == 2
@@ -215,3 +252,26 @@ def test_round_trip():
         pass
         if os.path.exists(tmp_path):
             fs.remove(tmp_path)
+
+
+def test_dehydrate():
+    broker = dr.run(report)
+    exc = next(iter(broker.tracebacks))
+    tb = broker.tracebacks[exc]
+
+    tmp_path = mkdtemp()
+    spec_the_data = TestSpecs.the_data
+    try:
+        h = Hydration(tmp_path)
+        h.dehydrate(spec_the_data, broker)
+        fn = ".".join([dr.get_name(spec_the_data), h.ser_name])
+        meta_data_json = os.path.join(h.meta_data, fn)
+        assert os.path.exists(meta_data_json)
+        with open(meta_data_json, 'r') as fp:
+            ret = json.load(fp)
+            assert "errors" in ret
+            assert ret["errors"][0] == tb
+            assert "Traceback" in tb
+            assert "Fake Datasource" in tb
+    finally:
+        fs.remove(tmp_path)
