@@ -15,7 +15,45 @@ from insights.client.config import InsightsConfig
 from insights.client.data_collector import CleanOptions
 from insights.contrib.soscleaner import SOSCleaner
 
-ReportItem = namedtuple("ReportItem", ("name", "relative_path"))
+
+class ReportFile:
+    def __init__(self, report_item):
+        self.report_item = report_item
+
+    @staticmethod
+    def result(relative_path):
+        return {
+            "object": {
+                "relative_path": relative_path
+            }
+        }
+
+    @property
+    def file_name(self):
+        return "%s.json" % self.report_item.name
+
+    @property
+    def contents(self):
+        return {
+            "name": self.report_item.name,
+            "results": self.report_item.results,
+        }
+
+
+class ReportItemSimpleFile(namedtuple("ReportItemSimpleFile", ("name", "relative_path"))):
+    @property
+    def results(self):
+        return ReportFile.result(self.relative_path)
+
+    @property
+    def relative_paths(self):
+        return [self.relative_path]
+
+
+class ReportItemGlobFile(namedtuple("ReportItemGlobFile", ("name", "relative_paths"))):
+    @property
+    def results(self):
+        return [ReportFile.result(relative_path) for relative_path in self.relative_paths]
 
 
 def _soscleaner():
@@ -38,18 +76,10 @@ def _mock_report_dir(report_items):
             mkdir(path)
 
         for report_item in report_items:
-            json_path = join(
-                meta_data_path, "%s.json" % report_item.name
-            )
+            report_file = ReportFile(report_item)
+            json_path = join(meta_data_path, report_file.file_name)
             with open(json_path, "w") as json_file:
-                meta_data_obj = {
-                    "name": report_item.name,
-                    "results": {
-                        "object": {
-                            "relative_path": report_item.relative_path
-                        }
-                    }
-                }
+                meta_data_obj = report_file.contents
                 dump(meta_data_obj, json_file)
 
         yield tmpdir
@@ -171,16 +201,16 @@ def test_excluded_specs():
         assert spec.find("insights.specs.Specs.") == 0
 
 
-def test_excluded_files():
+def test_excluded_files_simple_file():
     report_items = [
-        ReportItem(
+        ReportItemSimpleFile(
             "insights.specs.Specs.installed_rpms",
             "insights_commands/rpm_-qa_--qf_name_NAME_epoch_EPOCH_"
             "version_VERSION_release_RELEASE_arch_ARCH_"
             "installtime_INSTALLTIME_date_buildtime_BUILDTIME_"
             "vendor_VENDOR_buildhost_BUILDHOST_sigpgp_SIGPGP_pgpsig"
         ),
-        ReportItem(
+        ReportItemSimpleFile(
             "insights.specs.Specs.ip_addr",
             "insights_commands/ip_addr"
         )
@@ -191,14 +221,30 @@ def test_excluded_files():
         soscleaner.dir_path = tmpdir
         actual = soscleaner._excluded_files()
 
-    expected = [
-        report_item.relative_path
-        for report_item in report_items
-        if report_item.name in soscleaner.excluded_specs
-    ]
+    expected = report_items[0].relative_paths
     assert actual == expected
 
 
+def test_excluded_files_glob_file():
+    report_items = [
+        ReportItemGlobFile(
+            "insights.specs.Specs.dnf_modules",
+            ["etc/dnf/modules.d/ruby.module"]
+        ),
+        ReportItemGlobFile(
+            "insights.specs.Specs.dnsmasq_config",
+            ["etc/dnsmasq.conf"]
+        )
+    ]
+
+    soscleaner = _soscleaner()
+    with _mock_report_dir(report_items) as tmpdir:
+        soscleaner.dir_path = tmpdir
+        actual = soscleaner._excluded_files()
+
+    assert actual == report_items[0].relative_paths
+
+
 @patch("insights.contrib.soscleaner.SOSCleaner._clean_file")
 @patch("insights.contrib.soscleaner.SOSCleaner._excluded_files")
 @patch("insights.contrib.soscleaner.SOSCleaner._extract_sosreport")
